package com.qiaoba.common.database.config;

import com.alibaba.druid.pool.DruidDataSource;
import com.qiaoba.common.database.entity.DynamicDataSource;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;

/**
 * 全局跨域配置
 *
 * @author ailanyin
 * @version 1.0
 * @since 2021/10/15 0015 下午 16:43
 */
@Configuration
public class DynamicDataSourceConfig {
    /**
     * 把DynamicDataSourceContext 纳入容器管理，其他地方使用DynamicDataSourceConfig 类可以直接从容器取对象，并调用freshDataSource方法
     */
    @Bean
    @Primary
    public static DynamicDataSourceContext dataSource() {
        Map<Object, Object> targetDataSource = getDataSource();
        //把DynamicDataSourceContext纳入容器管理
        DynamicDataSourceContext dynamicDataSourceContext = new DynamicDataSourceContext();
        dynamicDataSourceContext.freshDataSource(targetDataSource);
        return dynamicDataSourceContext;
    }

    /**
     * 构建初始化数据源 TODO 生成中去其他地方获取初始化数据源(例如:表里面获取)
     *
     * @return
     */
    public static Map<Object, Object> getDataSource() {

        DynamicDataSource ds2 = new DynamicDataSource();
        ds2.setTenantCode("1");
        ds2.setDriver("com.mysql.cj.jdbc.Driver");
        ds2.setUrl("jdbc:mysql://121.5.136.69:3306/qiaoba-boot?useSSL=false&allowMultiQueries=true&useUnicode=true&characterEncoding=UTF-8&autoReconnect=true&useSSL=false&zeroDateTimeBehavior=convertToNull&serverTimezone=Asia/Shanghai");
        ds2.setUsername("root");
        ds2.setPassword("LpYN7LUoL?l0OSpR2");

        DynamicDataSource ds1 = new DynamicDataSource();
        ds1.setTenantCode("2");
        ds1.setDriver("com.mysql.cj.jdbc.Driver");
        ds1.setUrl("jdbc:mysql://120.79.217.22:3306/qiaoba-boot?useSSL=false&allowMultiQueries=true&useUnicode=true&characterEncoding=UTF-8&autoReconnect=true&useSSL=false&zeroDateTimeBehavior=convertToNull&serverTimezone=Asia/Shanghai");
        ds1.setUsername("root");
        ds1.setPassword("FeyZ7xZr6JtuKibm");
        Map<Object, Object> map = new HashMap<>();
        map.put(ds1.getTenantCode(), buildDataSource(ds1));
        map.put(ds2.getTenantCode(), buildDataSource(ds2));
        return map;
    }

    /**
     * 把数据源对象组装成HikariDataSource
     *
     * @param DynamicDataSource
     * @return
     */
    private static Object buildDataSource(DynamicDataSource DynamicDataSource) {
        DruidDataSource dataSource = new DruidDataSource();
        dataSource.setUrl(DynamicDataSource.getUrl());
        dataSource.setUsername(DynamicDataSource.getUsername());
        dataSource.setPassword(DynamicDataSource.getPassword());
        dataSource.setDriverClassName(DynamicDataSource.getDriver());
        dataSource.setInitialSize(5);
        dataSource.setMinIdle(10);
        dataSource.setMaxActive(20);
        try {
            dataSource.init();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        return dataSource;
    }
}
