package com.qiaoba.common.database.factories;

import com.qiaoba.common.database.config.DynamicDataSourceConfig;
import com.qiaoba.common.database.config.DynamicDataSourceContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import java.util.Map;

/**
 * 动态数据源的工厂，主要解决缓存依赖
 *
 * @version 1.0
 * @author ailanyin
 * @since 2023-04-25 21:47:34
 */
@Configuration
public class DynamicDataSourceFactory {

    /**
     * 把DynamicDataSourceContext 纳入容器管理，其他地方使用DynamicDataSourceConfig 类可以直接从容器取对象，并调用freshDataSource方法
     */
    @Bean
    @Primary
    public static DynamicDataSourceContext dataSource() {
        Map<Object, Object> targetDataSource = DynamicDataSourceConfig.getDataSource();
        //把DynamicDataSourceContext纳入容器管理
        DynamicDataSourceContext dynamicDataSourceContext = new DynamicDataSourceContext();
        dynamicDataSourceContext.freshDataSource(targetDataSource);
        return dynamicDataSourceContext;
    }
}
